@@ -84,7 +84,7 @@
 #define KDBUSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDBUSADDONS_NO_DEPRECATED
-#  define KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
+#  define KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56d00
 #endif
 #ifdef KDBUSADDONS_NO_DEPRECATED_WARNINGS
 #  define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE KDBUSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE 0x56c00
+#    define KDBUSADDONS_DEPRECATED_WARNINGS_SINCE 0x56d00
 #  endif
 #endif
 
